@@ -28,13 +28,11 @@ m_mainWindow(mainWindow)
 
     m_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("konversation/bookmarks.xml") );
 
-    if ( m_file.isEmpty() )
+    if ( m_file.isEmpty() ) {
         m_file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("konversation/bookmarks.xml") ;
+    }
 
-    KBookmarkManager *manager = KBookmarkManager::managerForFile( m_file, QStringLiteral("konversation"));
-    manager->setEditorOptions(i18n("Konversation Bookmarks Editor"), false);
-    manager->setUpdate( true );
-
+    auto *manager = new KBookmarkManager( m_file, this);
     m_bookmarkMenu = new KBookmarkMenu(manager, this, menu);
     m_mainWindow->actionCollection()->addActions(menu->actions());
 }
